You can not select more than 25 topics Topics must start with a letter or number, can include dashes ('-') and can be up to 35 characters long.
gentoo-overlay/mate-base/mate-control-center/files/mate-control-center-1.6.2-l...

16 lines
568 B

diff --git a/libslab/app-shell.c b/libslab/app-shell.c
index 3c33230..5f4af23 100644
--- a/libslab/app-shell.c
+++ b/libslab/app-shell.c
@@ -987,8 +987,8 @@ static void handle_menu_action_performed (Tile * launcher, TileEvent * event, Ti
return TRUE;
}
- /* discard mate-keyring-manager if CASA is installed */
- if ((exec && !strcmp (exec, "mate-keyring-manager"))
+ /* discard gnome-keyring-manager if CASA is installed */
+ if ((exec && !strcmp (exec, "gnome-keyring-manager"))
&& (path = g_find_program_in_path ("CASAManager.sh")))
{
g_free (path);